summaryrefslogtreecommitdiffstats
path: root/src/main.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'src/main.cpp')
-rw-r--r--src/main.cpp16
1 files changed, 8 insertions, 8 deletions
diff --git a/src/main.cpp b/src/main.cpp
index ca7ad52..d44b70c 100644
--- a/src/main.cpp
+++ b/src/main.cpp
@@ -19,22 +19,22 @@
* 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA. *
***************************************************************************/
-#include "kpowersave.h"
+#include "tdepowersave.h"
#include <kuniqueapplication.h>
#include <tdeaboutdata.h>
#include <tdecmdlineargs.h>
#include <tdelocale.h>
#include <kiconloader.h>
-#include "kpowersave_debug.h"
+#include "tdepowersave_debug.h"
/*!
* \file main.cpp
* \brief The file with the \ref kdemain class to start kpowersave.
*/
/*!
* \class kdemain
* \brief The kpowersave kdemain class, which is the startpoint of KPowersave.
* \author Thomas Renninger, <trenn@suse.de>
* \author Danny Kukawka, <dkukawka@suse.de>, <danny.kukawka@web.de>
* \date 2004 - 2007
@@ -52,7 +52,7 @@ bool trace = false;
extern "C"
int kdemain(int argc, char **argv)
{
- TDEAboutData about("kpowersave", I18N_NOOP("KPowersave"), version, description,
+ TDEAboutData about("tdepowersave", I18N_NOOP("TDEPowersave"), version, description,
TDEAboutData::License_GPL, I18N_NOOP("(c) 2004-2006, Danny Kukawka\n"
"(c) 2004 Thomas Renninger"));
@@ -76,16 +76,16 @@ int kdemain(int argc, char **argv)
TDECmdLineArgs *args = TDECmdLineArgs::parsedArgs();
if (!KUniqueApplication::start()) {
- fprintf(stderr, "KPowersave is already running!\n");
+ fprintf(stderr, "TDEPowersave is already running!\n");
exit(0);
}
KUniqueApplication app;
app.disableSessionManagement();
- kpowersave *mainWin = 0;
+ tdepowersave *mainWin = 0;
- mainWin = new kpowersave(args->isSet( "force-acpi-check" ), args->isSet( "dbg-trace" ));
+ mainWin = new tdepowersave(args->isSet( "force-acpi-check" ), args->isSet( "dbg-trace" ));
app.setMainWidget( mainWin );
mainWin->show();
@@ -19,22 +19,22 @@
/*!
* \file main.cpp
- * \brief The file with the \ref kdemain class to start kpowersave.
+ * \brief The file with the \ref kdemain class to start tdepowersave.
*/
/*!
@@ -19,22 +19,22 @@
/*!
* \class kdemain
- * \brief The kpowersave kdemain class, which is the startpoint of KPowersave.
+ * \brief The tdepowersave kdemain class, which is the startpoint of TDEPowersave.
* \author Thomas Renninger, <trenn@suse.de>
* \author Danny Kukawka, <dkukawka@suse.de>, <danny.kukawka@web.de>